# OVERRIDE RHEL VERSION HERE, RHEL BUILDSYSTEM DOESN'T HAVE DIST TAG
#%%global rhel 4

# Define Variables that must exist
%{?!rhel:%global rhel 0}
%{?!fedora:%global fedora 0}

# Map RHEL to Fedora version
%if 0%{?rhel} == 4
%global fedora 3
%global dist .el4
%endif
%if 0%{?rhel} == 5
%global fedora 6
%global dist .el5
%endif
%if 0%{?rhel} == 6
%global fedora 12
%global dist .el6
%endif

# Define variables to use in conditionals
%global force_sound_aplay       0
%global dbus_integration        0
%global gstreamer_integration   0
%global nm_integration          0
%global modular_x               0
%global dbus_glib_splt          0
%global bonjour_support         0
%global meanwhile_integration   0
%global use_gnome_open          0
%global perl_devel_separated    0
%global perl_embed_separated    0
%global api_docs                0
%global krb4_removed            0
%global nss_md2_disabled        0
%global vv_support              0
%global libidn_support          0
%global disable_silc            0
%global split_evolution         0
%global use_system_certs        0
%global use_system_libgadu      0

# RHEL4: Use ALSA aplay to output sounds because it lacks gstreamer
%if 0%{?fuduntu} < 5
%global force_sound_aplay       1
%endif
# RHEL4+ and FC5+: dbus, gstreamer, NetworkManager, modular X
%if 0%{?fuduntu} >= 5
%global dbus_integration        1
%global gstreamer_integration   1
%global nm_integration          1
%global modular_x               1
%endif
# RHEL4+ and FC6+: dbus-glib split, bonjour, meanwhile
%if 0%{?fuduntu} >= 6
%global dbus_glib_splt          1
%global bonjour_support         1
%global meanwhile_integration   1
%endif
# RHEL4 and RHEL5: Use gnome-open instead of xdg-open (RHEL4 and RHEL5)
%if 0%{?fuduntu} <= 6
%global use_gnome_open          1
%endif
# F7+: Perl devel separated out
%if 0%{?fuduntu} >= 7
%global perl_devel_separated    1
%endif
# F8+: Perl embed separated out, generate pidgin API documentation
%if 0%{?fuduntu} >= 8
%global perl_embed_separated    1
%global api_docs                1
%endif
# F10+: New NSS (3.12.3) disables weaker MD2 algorithm
%if 0%{?fuduntu} >= 10
%global nss_md2_disabled        1
%endif
# F11+: libidn for punycode domain support, voice and video support,
# use system SSL certificates
%if 0%{?fuduntu} >= 11
%global vv_support              1
%global libidn_support          1
%global use_system_certs        1
%endif
# F12+: krb4 removed
%if 0%{?fuduntu} >= 12
%global krb4_removed            1
%endif
# EL6: Disable SILC protocol
# (get rid of extra crypto lib for perpetually broken protocol that nobody uses)
# (the above comment is not necessarily the view held by all maintaners of this package)
%if 0%{?rhel} == 6
%global disable_silc            1
%endif
# F13+ Split Evolution plugin to separate package (#581144)
%if 0%{?fuduntu} >= 13
%global split_evolution         1
%endif
# F16+ Use system libgadu (#713888)
%if 0%{?fuduntu} >= 16
%global use_system_libgadu      1
%endif

Name:           pidgin
Version:        2.10.7
Release:        3%{?dist}
License:        GPLv2+ and GPLv2 and MIT
# GPLv2+ - libpurple, gnt, finch, pidgin, most prpls
# GPLv2 - silc & novell prpls
# MIT - Zephyr prpl
Group:          Applications/Internet
URL:            http://pidgin.im/
Source0:        http://downloads.sourceforge.net/pidgin/pidgin-%{version}.tar.bz2
Obsoletes:      gaim < 999:1
Provides:       gaim = 999:1

%if %{split_evolution}
Obsoletes:      pidgin <= 2.7.1-1%{?dist}
%endif

## Fedora pidgin defaults
# Only needs regenerating if Pidgin breaks backwards compatibility with prefs.xml
# 1) uninstall any non-default pidgin or libpurple plugins
# 2) run pidgin as new user 3) edit preferences 4) close 5) copy .purple/prefs.xml
# OR 1) edit manually
# - enable ExtPlacement plugin
# - enable History plugin
# - enable Message Notification plugin
#   Insert count of new messages into window title
#   Set window manager "URGENT" hint
# - disable buddy icon in buddy list
# - enable Logging (in HTML)
# - Browser "GNOME Default"
# - Smiley Theme "Default"
Source1:        purple-fedora-prefs.xml

## Patches 0-99: Fedora specific or upstream wont accept
Patch0:         pidgin-NOT-UPSTREAM-2.5.2-rhel4-sound-migration.patch
Patch1:		glibc.patch
Patch2:		ssl-nss-headers.patch
Patch3:		implicit-declaration.patch
Patch4:		pidgin-2.10.7-link-libirc-to-libsasl2.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-root
Summary:        A Gtk+ based multiprotocol instant messaging client

# Require Binary Compatible glib
# returns bogus value if glib2-devel is not installed in order for parsing to succeed
# bogus value wont make it into a real package
%global glib_ver %([ -a %{_libdir}/pkgconfig/glib-2.0.pc ] && pkg-config --modversion glib-2.0 | cut -d. -f 1,2 || echo -n "999")
BuildRequires:  glib2-devel
Requires:       glib2 >= %{glib_ver}
# Require exact libpurple
Requires:       libpurple%{?_isa} = %{version}-%{release}

Requires(pre):  GConf2
Requires(post): GConf2
Requires(preun): GConf2

# Basic Library Requirements
BuildRequires:  autoconf
BuildRequires:  libtool
BuildRequires:  startup-notification-devel
BuildRequires:  cyrus-sasl-devel
%if %{nss_md2_disabled}
BuildRequires:  nss-devel >= 3.12.3
%else
BuildRequires:  nss-devel
%endif
BuildRequires:  gtk2-devel
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  desktop-file-utils
BuildRequires:  ncurses-devel
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  libxml2-devel

%if ! %{krb4_removed}
# krb5 needed for Zephyr (FC1+)
BuildRequires:  krb5-devel
%endif
# gtkspell integration (FC1+)
BuildRequires:  gtkspell-devel
# Evolution integration (FC3+)
BuildRequires:  evolution-data-server-devel
# SILC integration (FC3+)
%if ! %{disable_silc}
BuildRequires:  libsilc-devel
%endif
# DBus integration (FC5+)
%if %{dbus_integration}
BuildRequires:  dbus-devel >= 0.60
BuildRequires:  python     >= 2.4
%endif
# GStreamer integration (FC5+)
%if %{gstreamer_integration}
BuildRequires:  gstreamer-devel >= 0.10
%endif
# NetworkManager integration (FC5+)
%if %{nm_integration}
BuildRequires:  NetworkManager-glib-devel
%endif
# Modular X (FC5+)
%if %{modular_x}
BuildRequires:  libSM-devel
BuildRequires:  libXScrnSaver-devel
%endif
# Preferred Applications (xdg for FC6+)
%if %{use_gnome_open}
Requires:       libgnome
%else
Requires:       xdg-utils
%endif
# DBus GLIB Split (FC6+)
%if %{dbus_glib_splt}
BuildRequires:  dbus-glib-devel >= 0.70
%endif
%if %{bonjour_support}
BuildRequires:  avahi-glib-devel
%endif
# Meanwhile integration (F6+)
%if %{meanwhile_integration}
BuildRequires:  meanwhile-devel
%endif
# Perl devel separated out (F7+)
%if %{perl_devel_separated}
BuildRequires:  perl-devel
%endif
# Perl embed separated out (F9+)
%if %{perl_embed_separated}
BuildRequires:  perl(ExtUtils::Embed)
%endif
# Voice and video support (F11+)
%if %{vv_support}
BuildRequires:  farsight2-devel
Requires:       gstreamer-plugins-good
%if 0%{?fuduntu} >= 12
Requires:       gstreamer-plugins-bad-free
%endif
%endif
# libidn punycode domain support (F11+)
%if %{libidn_support}
BuildRequires:  libidn-devel
%endif
# use system libgadu (F13+)
%if %{use_system_libgadu}
BuildRequires:  libgadu-devel
%endif

%if %{api_docs}
BuildRequires:  doxygen
%endif

%description
Pidgin allows you to talk to anyone using a variety of messaging
protocols including AIM, MSN, Yahoo!, Jabber, Bonjour, Gadu-Gadu,
ICQ, IRC, Novell Groupwise, QQ, Lotus Sametime, SILC, Simple and
Zephyr.  These protocols are implemented using a modular, easy to
use design.  To use a protocol, just add an account using the
account editor.

Pidgin supports many common features of other clients, as well as many
unique features, such as perl scripting, TCL scripting and C plugins.

Pidgin is not affiliated with or endorsed by America Online, Inc.,
Microsoft Corporation, Yahoo! Inc., or ICQ Inc.

%if %{split_evolution}
%package evolution
Summary:    Pidgin Evolution integration plugin
Group:      Applications/Internet
Requires:   %{name} = %{version}-%{release}
Obsoletes:  pidgin <= 2.7.1-1%{?dist}

%description evolution
This package contains the Evolution integration plugin for Pidgin.

%endif


%package devel
Summary:    Development headers and libraries for pidgin
Group:      Development/Libraries
Requires:   %{name} = %{version}-%{release}
Requires:   libpurple-devel = %{version}-%{release}
Requires:   pkgconfig
Requires:   gtk2-devel
Obsoletes:  gaim-devel
Provides:   gaim-devel = %{version}-%{release}


%description devel
The pidgin-devel package contains the header files, developer
documentation, and libraries required for development of Pidgin scripts
and plugins.

%package perl
Summary:    Perl scripting support for Pidgin
Group:      Applications/Internet
Requires:   libpurple = %{version}-%{release}
Requires:   libpurple-perl = %{version}-%{release}

%description perl
Perl plugin loader for Pidgin. This package will allow you to write or
use Pidgin plugins written in the Perl programming language.


%package -n libpurple
Summary:    libpurple library for IM clients like Pidgin and Finch
Group:      Applications/Internet
# Ensure elimination of gaim.i386 on x86_64
Obsoletes:  gaim < 999:1
%if %{meanwhile_integration}
Obsoletes:  gaim-meanwhile
%endif
Requires:   glib2 >= %{glib_ver}
# Bug #212817 Jabber needs cyrus-sasl plugins for authentication
Requires:   cyrus-sasl-plain cyrus-sasl-md5
# Use system SSL certificates (F11+)
%if %{use_system_certs}
Requires:   ca-certificates
%endif
# Workaround for accidental shipping of pidgin-docs
%if 0%{?rhel} == 5
Obsoletes:  pidgin-docs = 2.5.2
%endif

%description -n libpurple
libpurple contains the core IM support for IM clients such as Pidgin
and Finch.

libpurple supports a variety of messaging protocols including AIM, MSN,
Yahoo!, Jabber, Bonjour, Gadu-Gadu, ICQ, IRC, Novell Groupwise, QQ,
Lotus Sametime, SILC, Simple and Zephyr.


%package -n libpurple-devel
Summary:    Development headers, documentation, and libraries for libpurple
Group:      Applications/Internet
Requires:   libpurple = %{version}-%{release}
Requires:   pkgconfig
%if %{dbus_integration}
Requires:   dbus-devel >= 0.60
%endif
%if %{dbus_glib_splt}
Requires:   dbus-glib-devel >= 0.70
%endif

%description -n libpurple-devel
The libpurple-devel package contains the header files, developer
documentation, and libraries required for development of libpurple based
instant messaging clients or plugins for any libpurple based client.

%package -n libpurple-perl
Summary:    Perl scripting support for libpurple
Group:      Applications/Internet
Requires:   libpurple = %{version}-%{release}
Requires:   perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description -n libpurple-perl
Perl plugin loader for libpurple. This package will allow you to write or
use libpurple plugins written in the Perl programming language.


%package -n libpurple-tcl
Summary:    Tcl scripting support for libpurple
Group:      Applications/Internet
Requires:   libpurple = %{version}-%{release}

%description -n libpurple-tcl
Tcl plugin loader for libpurple. This package will allow you to write or
use libpurple plugins written in the Tcl programming language.


%package -n finch
Summary:    A text-based user interface for Pidgin
Group:      Applications/Internet
Requires:   glib2 >= %{glib_ver}
Requires:   libpurple = %{version}-%{release}

%description -n finch
A text-based user interface for using libpurple.  This can be run from a
standard text console or from a terminal within X Windows.  It
uses ncurses and our homegrown gnt library for drawing windows
and text.


%package -n finch-devel
Summary:    Headers etc. for finch stuffs
Group:      Applications/Internet
Requires:   finch = %{version}-%{release}
Requires:   libpurple-devel = %{version}-%{release}
Requires:   pkgconfig
Requires:   ncurses-devel

%description -n finch-devel
The finch-devel package contains the header files, developer
documentation, and libraries required for development of Finch scripts
and plugins.

%if %{api_docs}
%package -n pidgin-docs
Summary:    API docs for pidgin and libpurple
Group:      Applications/Internet
Requires:   pidgin = %{version}-%{release}
Provides:   libpurple-docs = %{version}-%{release}

%description -n pidgin-docs
Doxygen generated API documentation.

%endif

%prep
echo "FEDORA=%{fuduntu} RHEL=%{rhel}"
%setup -q
## Patches 0-99: Fedora specific or upstream wont accept
%if %{force_sound_aplay}
%patch0 -p1 -b .aplay
%endif

%patch1 -p1 -b .glibc
%patch2 -p1 -b .ssl-nss
%patch3 -p1 -b .implicit
%patch4 -p1 -b .libsasl2

# Our preferences
cp %{SOURCE1} prefs.xml

# RHEL5 and earlier did not have xdg-open, so use gnome-open instead
if [ "%{use_gnome_open}" == "1" ]; then
    sed -i "s/value='xdg-open'/value='gnome-open'/" prefs.xml
fi

# Bug #528796: Get rid of #!/usr/bin/env python
# Upstream refuses to use ./configure --python-path= in these scripts.
for file in finch/plugins/pietray.py libpurple/purple-remote libpurple/plugins/dbus-buddyicons-example.py \
            libpurple/plugins/startup.py libpurple/purple-url-handler libpurple/purple-notifications-example; do
    sed -i 's/env python/python/' $file
done

%build
SWITCHES="--with-extraversion=%{release}"
%if ! %{krb4_removed}
    SWITCHES="$SWITCHES --with-krb4"
%endif
    SWITCHES="$SWITCHES --enable-perl"
    SWITCHES="$SWITCHES --enable-gevolution"
%if %{dbus_integration}
    SWITCHES="$SWITCHES --enable-dbus"
%else
    SWITCHES="$SWITCHES --disable-dbus"
%endif
%if %{nm_integration}
    SWITCHES="$SWITCHES --enable-nm"
%endif
%if %{gstreamer_integration}
    SWITCHES="$SWITCHES --enable-gstreamer"
%else
    SWITCHES="$SWITCHES --disable-gstreamer"
%endif
%if ! %{bonjour_support}
    SWITCHES="$SWITCHES --disable-avahi"
%endif
%if ! %{meanwhile_integration}
    SWITCHES="$SWITCHES --disable-meanwhile"
%endif
%if ! %{libidn_support}
    SWITCHES="$SWITCHES --disable-idn"
%endif
%if ! %{vv_support}
    SWITCHES="$SWITCHES --disable-vv"
%endif
%if %{use_system_certs}
    SWITCHES="$SWITCHES --with-system-ssl-certs=/etc/pki/tls/certs"
%endif

# FC5+ automatic -fstack-protector-all switch
export RPM_OPT_FLAGS=${RPM_OPT_FLAGS//-fstack-protector/-fstack-protector-all}
export CFLAGS="$RPM_OPT_FLAGS"

# gnutls is buggy so use mozilla-nss on all distributions
%configure --enable-gnutls=no --enable-nss=yes --enable-cyrus-sasl \
           --enable-tcl --enable-tk \
           --disable-schemas-install $SWITCHES

make %{?_smp_mflags} LIBTOOL=/usr/bin/libtool

# one_time_password plugin, included upstream but not built by default
cd libpurple/plugins/
make one_time_password.so
cd -

%if %{api_docs}
make docs
find doc/html -empty -delete
%endif

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install LIBTOOL=/usr/bin/libtool

install -m 0755 libpurple/plugins/one_time_password.so $RPM_BUILD_ROOT%{_libdir}/purple-2/

desktop-file-install --vendor pidgin --delete-original              \
                     --add-category X-Red-Hat-Base                  \
                     --dir $RPM_BUILD_ROOT%{_datadir}/applications  \
                     $RPM_BUILD_ROOT%{_datadir}/applications/pidgin.desktop

# remove libtool libraries and static libraries
find $RPM_BUILD_ROOT \( -name "*.la" -o -name "*.a" \) -exec rm -f {} ';'
# remove the perllocal.pod file and other unrequired perl bits
find $RPM_BUILD_ROOT -type f -name perllocal.pod -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name .packlist -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name '*.bs' -empty -exec rm -f {} ';'
# remove relnot.so plugin since it is unusable for our package
rm -f $RPM_BUILD_ROOT%{_libdir}/pidgin/relnot.so
# remove dummy nullclient
rm -f $RPM_BUILD_ROOT%{_bindir}/nullclient
# install Fedora pidgin default prefs.xml
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/purple/
install -m 644 prefs.xml $RPM_BUILD_ROOT%{_sysconfdir}/purple/prefs.xml

# remove non-plugin unrequired library symlinks
rm -f $RPM_BUILD_ROOT%{_libdir}/purple-2/liboscar.so
rm -f $RPM_BUILD_ROOT%{_libdir}/purple-2/libjabber.so
rm -f $RPM_BUILD_ROOT%{_libdir}/purple-2/libymsg.so

# make sure that we can write to all the files we've installed
# so that they are properly stripped
chmod -R u+w $RPM_BUILD_ROOT/*

%find_lang pidgin

# symlink /usr/bin/gaim to new pidgin name
ln -sf pidgin $RPM_BUILD_ROOT%{_bindir}/gaim

%if %{api_docs}
rm -rf html
rm -f doc/html/installdox
mv doc/html/ html/
mkdir -p $RPM_BUILD_ROOT%{_datadir}/gtk-doc/html/
ln -sf ../../doc/pidgin-docs-%{version}/html/ \
    $RPM_BUILD_ROOT%{_datadir}/gtk-doc/html/pidgin
%endif

%pre
if [ "$1" -gt 1 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
        %{_sysconfdir}/gconf/schemas/purple.schemas >/dev/null || :
    killall -HUP gconfd-2 &> /dev/null || :
fi

%post
touch --no-create %{_datadir}/icons/hicolor || :
[ -x %{_bindir}/gtk-update-icon-cache ] && \
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule \
    %{_sysconfdir}/gconf/schemas/purple.schemas > /dev/null || :
killall -HUP gconfd-2 &> /dev/null || :

%post -n libpurple -p /sbin/ldconfig

%post -n finch -p /sbin/ldconfig

%preun
if [ "$1" -eq 0 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
        %{_sysconfdir}/gconf/schemas/purple.schemas > /dev/null || :
    killall -HUP gconfd-2 &> /dev/null || :
fi

%postun
touch --no-create %{_datadir}/icons/hicolor || :
[ -x %{_bindir}/gtk-update-icon-cache ] && \
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :

%postun -n libpurple -p /sbin/ldconfig

%postun -n finch -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc NEWS COPYING AUTHORS README ChangeLog doc/PERL-HOWTO.dox
%{_bindir}/pidgin
%{_bindir}/gaim
%{_libdir}/pidgin/
%exclude %{_libdir}/pidgin/perl
%if %{split_evolution}
%exclude %{_libdir}/pidgin/gevolution.so
%endif
%{_mandir}/man1/pidgin.*
%{_datadir}/applications/pidgin.desktop
%{_datadir}/pixmaps/pidgin/
%{_datadir}/icons/hicolor/*/apps/pidgin.*
%{_sysconfdir}/gconf/schemas/purple.schemas

%if %{split_evolution}
%files evolution
%defattr(-,root,root,-)
%{_libdir}/pidgin/gevolution.so
%endif

%files perl
%defattr(-,root,root,-)
%{_mandir}/man3/Pidgin*
%{_libdir}/pidgin/perl/

%files devel
%defattr(-,root,root,-)
%{_includedir}/pidgin/
%{_libdir}/pkgconfig/pidgin.pc

%files -f pidgin.lang -n libpurple
%defattr(-,root,root,-)
%doc COPYING
%{_libdir}/purple-2/
%exclude %{_libdir}/purple-2/perl
%{_libdir}/libpurple.so.*
%{_datadir}/sounds/purple/
%{_datadir}/purple
%dir %{_sysconfdir}/purple
%config(noreplace) %{_sysconfdir}/purple/prefs.xml
%if %{dbus_integration}
%{_bindir}/purple-client-example
%{_bindir}/purple-remote
%{_bindir}/purple-send
%{_bindir}/purple-send-async
%{_bindir}/purple-url-handler
%{_libdir}/libpurple-client.so.*
#%%{_datadir}/dbus-1/services/pidgin.service
%doc libpurple/purple-notifications-example
%endif
%exclude %{_libdir}/purple-2/tcl.so
%exclude %{_libdir}/purple-2/perl.so
%exclude %{_libdir}/purple-2/perl/

%files -n libpurple-devel
%defattr(-,root,root,-)
%{_datadir}/aclocal/purple.m4
%{_libdir}/libpurple.so
%{_includedir}/libpurple/
%{_libdir}/pkgconfig/purple.pc
%if %{dbus_integration}
%{_libdir}/libpurple-client.so
%endif

%files -n libpurple-perl
%defattr(-,root,root,-)
%{_mandir}/man3/Purple*
%{_libdir}/purple-2/perl.so
%{_libdir}/purple-2/perl/

%files -n libpurple-tcl
%defattr(-,root,root,-)
%{_libdir}/purple-2/tcl.so

%files -n finch
%defattr(-,root,root,-)
%{_bindir}/finch
%{_libdir}/finch/
%{_libdir}/gnt/
%{_libdir}/libgnt.so.*
%{_mandir}/man1/finch.*

%files -n finch-devel
%defattr(-,root,root,-)
%{_includedir}/finch/
%{_includedir}/gnt/
%{_libdir}/libgnt.so
%{_libdir}/pkgconfig/gnt.pc
%{_libdir}/pkgconfig/finch.pc

%if %{api_docs}
%files -n pidgin-docs
%defattr(-,root,root,-)
%doc html
%{_datadir}/gtk-doc/html/*
%endif

%changelog
* Mon Feb 18 2013 Johnny Brinsko <tripgod@fuduntu.org> - 2.10.7-3
- Link against libsasl2 for IRC support

* Sun Feb 17 2013 Johnny Brinsko <tripgod@fuduntu.org> - 2.10.7-2
- Build against nss-3.13.6

* Fri Feb 16 2013 Johnny Brinsko <tripgod@fuduntu.org> - 2.10.7-1
- New upstream release

* Sat Jul 07 2012 Andrew Wyatt <andrew@fuduntu.org> - 2.10.6-1
- New upstream release

* Sat May 12 2012  Andrew Wyatt <andrew@fuduntu.org> - 2.10.4-1
- New upstream release

* Tue Apr 10 2012 Andrew Wyatt <andrew@fuduntu.org> - 2.10.3-1
- New upstream release

* Thu Mar 15 2012 Andrew Wyatt <andrew@fuduntu.org> - 2.10.2-1
- New upstream sources

* Sat Feb 04 2012 Andrew Wyatt <andrew@fuduntu.org> - 2.10.1-1
- Built for Fuduntu

* Sun Jan 01 2012 Andrew Wyatt <andrew@fuduntu.org> - 2.10.0-3
- Built for Fuduntu

